==> lxqt-policykit_0.14.1.orig.tar.xz: lxqt-policykit-0.14.1/translations/lxqt-policykit-agent_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../src/policykitagent.cpp" line="71"/>
        <location filename="../src/policykitagent.cpp" line="158"/>
        <source>PolicyKit Information</source>
        <translation>PolicyKit 信息</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="71"/>
        <source>Another authentization in progress. Please try it again later.</source>
        <translation>另外的认证正在进行，请稍后再试。</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="139"/>
        <source>Authorization Failed</source>
        <translation>认证失败</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="139"/>
        <source>Authorization failed for some reason</source>
        <translation>认证因某些原因失败</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="153"/>
        <source>PolicyKit Error</source>
        <translation>PolicyKit 错误</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>需要认证</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>身份:</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>密码:</translation>
    </message>
</context>
</TS>

==> lxqt-policykit_0.17.0.orig.tar.xz: lxqt-policykit-0.17.0/translations/lxqt-policykit-agent_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../src/policykitagent.cpp" line="75"/>
        <location filename="../src/policykitagent.cpp" line="169"/>
        <source>PolicyKit Information</source>
        <translation>PolicyKit 信息</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="75"/>
        <source>Another authentication is in progress. Please try again later.</source>
        <translation>别的授权正在进行。请稍后再试。</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="145"/>
        <source>Authorization Failed</source>
        <translation>认证失败</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="145"/>
        <source>Authorization failed for some reason</source>
        <translation>认证因某些原因失败</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="162"/>
        <source>PolicyKit Error</source>
        <translation>PolicyKit 错误</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>需要认证</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>身份:</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>密码:</translation>
    </message>
</context>
</TS>
